==> amsdal_server-0.0.26-py3-none-any.whl: amsdal_server/apps/classes/mixins/model_class_info.py <==
from amsdal_models.classes.manager import ClassManager
from amsdal_models.classes.model import Model
from amsdal_models.querysets.base_queryset import QuerySet
from amsdal_utils.models.enums import SchemaTypes
from amsdal_utils.query.utils import Q

from amsdal_server.apps.classes.errors import ClassNotFoundError


class ModelClassMixin:
    @classmethod
    def get_model_class_by_name(cls, class_name: str) -> type[Model]:
        class_item: Model | None = (
            cls.get_class_objects_qs().latest().filter(title=class_name).first().execute()  # type: ignore[attr-defined]
        )

        if not class_item:
            msg = f'Class not found: {class_name}'
            raise ClassNotFoundError(class_name, msg)

        return cls.get_model_class(class_item)

    @classmethod
    def get_model_class(cls, class_item: Model) -> type[Model]:
        class_manager = ClassManager()
        model_class = class_manager.import_model_class(
            class_item.title,
            class_item.get_metadata().class_schema_type,
        )

        return model_class

    @classmethod
    def get_class_objects_qs(cls) -> QuerySet:
        class_manager = ClassManager()
        class_object: type[Model] = class_manager.import_model_class('ClassObject', SchemaTypes.CORE)

        return class_object.objects.filter(
            (
                Q(_metadata__class_schema_type=SchemaTypes.CONTRIB)
                | Q(_metadata__class_schema_type=SchemaTypes.USER)
                | Q(title='File')  # ugly hack
            ),
            _metadata__is_deleted=False,
            _metadata__next_version__isnull=True,
        )

==> amsdal_server-0.1.1-py3-none-any.whl: amsdal_server/apps/classes/mixins/model_class_info.py <==
from amsdal_models.classes.manager import ClassManager
from amsdal_models.classes.model import Model
from amsdal_models.enums import MetaClasses
from amsdal_models.querysets.base_queryset import QuerySet
from amsdal_utils.models.enums import SchemaTypes
from amsdal_utils.query.utils import Q

from amsdal_server.apps.classes.errors import ClassNotFoundError


class ModelClassMixin:
    @classmethod
    def get_model_class_by_name(cls, class_name: str) -> type[Model]:
        class_item: Model | None = (
            cls.get_class_objects_qs().latest().filter(_address__object_id=class_name).first().execute()
        )

        if not class_item:
            msg = f'Class not found: {class_name}'
            raise ClassNotFoundError(class_name, msg)

        return cls.get_model_class(class_item)

    @classmethod
    def get_model_class(cls, class_item: Model) -> type[Model]:
        class_manager = ClassManager()
        model_class = class_manager.import_model_class(
            class_item.object_id,
            class_item.get_metadata().class_schema_type,
        )

        return model_class

    @classmethod
    def get_class_objects_qs(cls) -> QuerySet:  # type: ignore[type-arg]
        class_manager = ClassManager()
        class_object: type[Model] = class_manager.import_model_class('ClassObject', SchemaTypes.CORE)

        return class_object.objects.filter(
            (
                Q(_metadata__class_schema_type=SchemaTypes.CONTRIB)
                | Q(_metadata__class_schema_type=SchemaTypes.USER)
                | Q(_address__object_id='File')  # ugly hack
            ),
            meta_class=MetaClasses.CLASS_OBJECT,
            _metadata__is_deleted=False,
            _metadata__next_version__isnull=True,
        )

    @classmethod
    def get_class_object_metas_qs(cls, class_objects: list[Model] | None = None) -> QuerySet:  # type: ignore[type-arg]
        class_manager = ClassManager()
        class_object: type[Model] = class_manager.import_model_class('ClassObjectMeta', SchemaTypes.CORE)
        qs = class_object.objects.filter(
            _metadata__is_deleted=False,
            _metadata__next_version__isnull=True,
        )

        if class_objects:
            qs = qs.filter(
                _address__object_id__in=[class_object.object_id for class_object in class_objects],
            )

        return qs
